==> forms_to_email-8.x-1.1.tar.gz: forms_to_email/src/Generator/FormsToEmailGenerateEmail.php <==
<?php

namespace Drupal\forms_to_email\Generator;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslationInterface;

/**
 * Class FormsToEmailGenerateEmail.
 *
 * @package Drupal\forms_to_email\Generator
 */
class FormsToEmailGenerateEmail {

  private $form;
  private $formState;

  // Define the module name and key to log any error.
  const KEY_PROJECT = 'forms_to_email';
  const KEY_MESSAGE = 'forms_to_email_send_mail';

  use StringTranslationTrait;

  /**
   * FormsToEmailGenerateEmail constructor.
   *
   * @param array $form
   *   An array with form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   An array with form state values.
   * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
   *   The string translation service.
   */
  public function __construct(array $form, FormStateInterface $form_state, TranslationInterface $string_translation) {
    $this->form = $form;
    $this->formState = $form_state;
    $this->stringTranslation = $string_translation;
  }

  /**
   * Retrieves the configuration data from admin settings.
   *
   * @return array
   *   An array with all configuration needed.
   */
  public function getConfigData() {
    $config = \Drupal::config('forms_to_email.settings');

    return [
      'from' => $config->get('forms_to_email_from'),
      'to' => $config->get('forms_to_email_to'),
      'subject' => $config->get('forms_to_email_subject'),
      'redirects' => $config->get('forms_to_email_default_redirect_success'),
      'error_message' => $this->t('An error occurred while sending your email. Please try again later.'),
    ];
  }

  /**
   * Get the values from modules.
   *
   * @return array
   *   An array with all data.
   */
  public function prepareModulesInvokeData() {
    $data_values = \Drupal::moduleHandler()->invokeAll('set_values', [$this->form, $this->formState]);

    if (empty($data_values)) {

      foreach ($this->formState->getValues() as $key => $value) {

        if (is_array($value)) {
          $value = implode(", ", $value);
        }

        $data_values[$key] = $value;
      }
    }

    return $data_values;
  }

  /**
   * Get the redirect page.
   *
   * @param string $redirects
   *   The redirect options.
   * @param string $form_id
   *   The form id.
   *
   * @return null|string
   *   The page alias to be redirected.
   */
  public function getRedirectPage($redirects, $form_id) {
    $redirects = explode(PHP_EOL, $redirects);
    $redirect_page = NULL;

    foreach ($redirects as $redirect) {

      $redirect = explode('|', $redirect);
      $id = $redirect[0];

      if ($id == $form_id) {
        $redirect_page = trim($redirect[1]);
        break;
      }
    }

    return $redirect_page;
  }

  /**
   * Send the email.
   *
   * @param array $data
   *   An array with config and values.
   *
   * @return bool
   *   TRUE|FALSE if the email was sent.
   */
  public function sendFormToEmail(array $data, $form) {
    if (empty($data)) {
      return FALSE;
    }

    // Get all the needed variables to send the email.
    $to = $data['to'];
    $key_project = $data['key_project'];
    $key_message = $data['key_message'];
    $langcode = \Drupal::currentUser()->getPreferredLangcode();

    $values = $this->removeIgnoredFields($data['values']);

    $body = $this->prepareEmailBody($values, $data['label'], $form);

    // Set the email parameters.
    $params['body'] = $body;
    $params['subject'] = $data['subject'];
    $params['from'] = $data['from'];

    // Send the email.
    $mailManager = \Drupal::service('plugin.manager.mail');
    $mail = $mailManager->mail($key_project, $key_message, $to, $langcode, $params, NULL, TRUE);

    return $mail['result'];
  }

  /**
   * Remove ignored fields from email.
   *
   * @param array $data
   *   An array with all data that will be send.
   *
   * @return mixed
   *   An array without excluded fields, if they exists.
   */
  public function removeIgnoredFields(array $data) {
    $fields_to_ignore = \Drupal::config('forms_to_email.settings')->get('forms_to_email_fields_to_ignore');
    $fields_to_ignore = explode(PHP_EOL, $fields_to_ignore);

    foreach ($fields_to_ignore as $field_to_ignore) {

      $field_to_ignore = trim($field_to_ignore);

      if (!empty($data[$field_to_ignore])) {
        unset($data[$field_to_ignore]);
      }
    }

    return $data;
  }

  /**
   * Remove Password Fields.
   */
  public function removePasswordFields(&$values, $form) {

    if (empty($values)) {
      return FALSE;
    }

    foreach ($values as $key => $value) {

      $key = trim($key);

      if ($key == 'pass') {
        $values[$key] = '****';
        continue;
      }

      if (empty($form[$key]['#type'])) {
        continue;
      }

      $type = $form[$key]['#type'];

      if ($type == 'password') {
        $values[$key] = '****';
      }
    }
  }

  /**
   * Prepare the email body.
   *
   * @param array $values
   *   An array with all fields.
   * @param string $body
   *   The initial body.
   *
   * @return string
   *   The body formatted with information and values.
   */
  public function prepareEmailBody(array $values, $body, $form) {

    $this->removePasswordFields($values, $form);

    foreach ($values as $label => $value) {

      // Strip tags.
      $label = strip_tags($label);
      $value = strip_tags($value);

      // Clear special chars.
      $label = preg_replace("/[^ \w]+/", "", $label);

      $body .= PHP_EOL . '__________________________________________' . PHP_EOL . $label . ': ' . $value;
    }

    return $body;
  }

  /**
   * Prepare the data needed.
   *
   * @return array
   *   An array with configuration and field values.
   */
  public function prepareMailData() {

    $config_data = $this->getConfigData();
    $data_values = $this->prepareModulesInvokeData();
    $redirect_page = $this->getRedirectPage($config_data['redirects'], $this->form['#form_id']);

    $config_data['values'] = $data_values;
    $config_data['redirect'] = $redirect_page;
    $config_data['label'] = $this->t('Informations:');

    return $config_data;
  }

  /**
   * Getter for key project.
   *
   * @return string
   *   The key project.
   */
  public static function getKeyProject() {
    return self::KEY_PROJECT;
  }

  /**
   * Getter for key message.
   *
   * @return string
   *   The key message.
   */
  public static function getKeyMessage() {
    return self::KEY_MESSAGE;
  }

}

==> forms_to_email-8.x-1.2.tar.gz: forms_to_email/src/Generator/FormsToEmailGenerateEmail.php <==
<?php

namespace Drupal\forms_to_email\Generator;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslationInterface;

/**
 * Class FormsToEmailGenerateEmail.
 *
 * @package Drupal\forms_to_email\Generator
 */
class FormsToEmailGenerateEmail {

  private $form;
  private $formState;

  // Define the module name and key to log any error.
  const KEY_PROJECT = 'forms_to_email';
  const KEY_MESSAGE = 'forms_to_email_send_mail';

  use StringTranslationTrait;

  /**
   * FormsToEmailGenerateEmail constructor.
   *
   * @param array $form
   *   An array with form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   An array with form state values.
   * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
   *   The string translation service.
   */
  public function __construct(array $form, FormStateInterface $form_state, TranslationInterface $string_translation) {
    $this->form = $form;
    $this->formState = $form_state;
    $this->stringTranslation = $string_translation;
  }

  /**
   * Retrieves the configuration data from admin settings.
   *
   * @return array
   *   An array with all configuration needed.
   */
  public function getConfigData() {
    $config = \Drupal::config('forms_to_email.settings');

    return [
      'from' => $config->get('forms_to_email_from'),
      'to' => $config->get('forms_to_email_to'),
      'subject' => $config->get('forms_to_email_subject'),
      'redirects' => $config->get('forms_to_email_default_redirect_success'),
      'error_message' => $this->t('An error occurred while sending your email. Please try again later.'),
    ];
  }

  /**
   * Get the values from modules.
   *
   * @return array
   *   An array with all data.
   */
  public function prepareModulesInvokeData() {
    $data_values = \Drupal::moduleHandler()->invokeAll('set_values', [$this->form, $this->formState]);

    if (empty($data_values)) {

      foreach ($this->formState->getValues() as $key => $value) {

        if (is_array($value)) {
          $value = implode(", ", $value);
        }

        $data_values[$key] = $value;
      }
    }

    return $data_values;
  }

  /**
   * Get the redirect page.
   *
   * @param string $redirects
   *   The redirect options.
   * @param string $form_id
   *   The form id.
   *
   * @return null|string
   *   The page alias to be redirected.
   */
  public function getRedirectPage($redirects, $form_id) {
    $redirects = explode(PHP_EOL, $redirects);
    $redirect_page = NULL;

    foreach ($redirects as $redirect) {

      $redirect = explode('|', $redirect);
      $id = $redirect[0];

      if ($id == $form_id) {
        $redirect_page = trim($redirect[1]);
        break;
      }
    }

    return $redirect_page;
  }

  /**
   * Send the email.
   *
   * @param array $data
   *   An array with config and values.
   * @param array $form
   *   Form values.
   *
   * @return bool
   *   TRUE|FALSE if the email was sent.
   */
  public function sendFormToEmail(array $data, array $form) {
    if (empty($data)) {
      return FALSE;
    }

    // Get all the needed variables to send the email.
    $to = $data['to'];
    $key_project = $data['key_project'];
    $key_message = $data['key_message'];
    $langcode = \Drupal::currentUser()->getPreferredLangcode();

    $values = $this->removeIgnoredFields($data['values']);

    $body = $this->prepareEmailBody($values, $data['label'], $form);

    // Set the email parameters.
    $params['body'] = $body;
    $params['subject'] = $data['subject'];
    $params['from'] = $data['from'];

    // Send the email.
    $mailManager = \Drupal::service('plugin.manager.mail');
    $mail = $mailManager->mail($key_project, $key_message, $to, $langcode, $params, NULL, TRUE);

    return $mail['result'];
  }

  /**
   * Remove ignored fields from email.
   *
   * @param array $data
   *   An array with all data that will be send.
   *
   * @return mixed
   *   An array without excluded fields, if they exists.
   */
  public function removeIgnoredFields(array $data) {
    $fields_to_ignore = \Drupal::config('forms_to_email.settings')->get('forms_to_email_fields_to_ignore');
    $fields_to_ignore = explode(PHP_EOL, $fields_to_ignore);

    foreach ($fields_to_ignore as $field_to_ignore) {

      $field_to_ignore = trim($field_to_ignore);

      if (!empty($data[$field_to_ignore])) {
        unset($data[$field_to_ignore]);
      }
    }

    return $data;
  }

  /**
   * Remove Password Fields.
   */
  public function removePasswordFields(&$values, $form) {

    if (empty($values)) {
      return FALSE;
    }

    foreach ($values as $key => $value) {

      $key = trim($key);

      if ($key == 'pass') {
        $values[$key] = '****';
        continue;
      }

      if (empty($form[$key]['#type'])) {
        continue;
      }

      $type = $form[$key]['#type'];

      if ($type == 'password') {
        $values[$key] = '****';
      }
    }
  }

  /**
   * Prepare the email body.
   *
   * @param array $values
   *   An array with all fields.
   * @param string $body
   *   The initial body.
   * @param array $form
   *   Form values.
   *
   * @return string
   *   The body formatted with information and values.
   */
  public function prepareEmailBody(array $values, $body, array $form) {

    $this->removePasswordFields($values, $form);

    foreach ($values as $label => $value) {

      // Strip tags.
      $label = strip_tags($label);
      $value = strip_tags($value);

      // Clear special chars.
      $label = preg_replace("/[^ \w]+/", "", $label);

      $body .= PHP_EOL . '__________________________________________' . PHP_EOL . $label . ': ' . $value;
    }

    return $body;
  }

  /**
   * Prepare the data needed.
   *
   * @return array
   *   An array with configuration and field values.
   */
  public function prepareMailData() {

    $config_data = $this->getConfigData();
    $data_values = $this->prepareModulesInvokeData();
    $redirect_page = $this->getRedirectPage($config_data['redirects'], $this->form['#form_id']);

    $config_data['values'] = $data_values;
    $config_data['redirect'] = $redirect_page;
    $config_data['label'] = $this->t('Informations:');

    return $config_data;
  }

  /**
   * Getter for key project.
   *
   * @return string
   *   The key project.
   */
  public static function getKeyProject() {
    return self::KEY_PROJECT;
  }

  /**
   * Getter for key message.
   *
   * @return string
   *   The key message.
   */
  public static function getKeyMessage() {
    return self::KEY_MESSAGE;
  }

}
